==> eiffelstudio-18.11.10.2592.tar: F_code/C4/i1189.c <==
/*
 * Code for class I18N_BINARY_SEARCH_ARRAY_DICTIONARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1189.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.make */
void F221_3301 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	F220_3285(Current, arg1);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,933,0xFF01,416,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F934_8254(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTLE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.extend */
void F221_3302 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	F934_8281(RTCW(tr1), arg1, ti4_1);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_))++;
	F221_3303(Current);
	RTLE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.search_index_and_insert */
void F221_3303 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLR(5,loc7);
	RTLR(6,tr2);
	RTLIU(7);
	
	RTGC;
	loc9 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc9 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L));
	if ((EIF_BOOLEAN) (loc9 > ((EIF_INTEGER_32) 1L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc4 = F934_8260(RTCW(tr1), loc9);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc5 = F934_8260(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc6 = F934_8260(RTCW(tr1), (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)));
		tb1 = F417_5364(RTCW(loc4), loc5);
		if (tb1) {
			loc8 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		} else {
			tb1 = F416_5348(RTCW(loc4), loc6);
			if (tb1) {
				loc8 = (EIF_INTEGER_32) loc9;
			} else {
				loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 2L));
				for (;;) {
					if ((EIF_BOOLEAN) (loc1 > loc2)) break;
					tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
					tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
					loc3 = (EIF_INTEGER_32) tu4_1;
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					loc7 = F934_8260(RTCW(tr1), loc3);
					tb1 = F417_5364(RTCW(loc4), loc7);
					if (tb1) {
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
					} else {
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
					}
				}
				loc8 = (EIF_INTEGER_32) loc1;
			}
		}
		if ((EIF_BOOLEAN)(loc8 != loc9)) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F934_8284(RTCW(tr1), tr2, loc8, (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)), (EIF_INTEGER_32) (loc8 + ((EIF_INTEGER_32) 1L)));
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F934_8279(RTCW(tr1), loc4, loc8);
		}
	}
	RTLE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.has_index */
EIF_INTEGER_32 F221_3304 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc5 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc6);
	RTLR(2,arg1);
	RTLR(3,loc12);
	RTLR(4,tr1);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTGC;
	loc7 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc7 - ((EIF_INTEGER_32) 1L));
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	loc2 = (EIF_INTEGER_32) loc7;
	loc6 = F1124_9648(RTCW(arg1));
	for (;;) {
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || loc5)) break;
		tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
		tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
		loc3 = (EIF_INTEGER_32) tu4_1;
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F934_8260(RTCW(tr1), loc3);
		loc12 = tr1;
		if ((EIF_TRUE)) {
			loc4 = F417_5358(loc12);
		} else {
			tr1 = RTLNS(eif_new_type(1128, 0x01).id, 1128, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1124_9589(RTCW(tr1));
			loc4 = (EIF_REFERENCE) tr1;
		}
		tb1 = F1127_9747(RTCW(loc6), loc4);
		if (tb1) {
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
		} else {
			tb1 = F416_5348(RTCW(loc6), loc4);
			if (tb1) {
				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
			} else {
				loc5 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				Result = (EIF_INTEGER_32) loc3;
				loc1++;
			}
		}
	}
	if ((EIF_BOOLEAN)(loc5 == (EIF_BOOLEAN) 0)) {
		RTLE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	}
	RTLE;
	return Result;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.singular_in_context */
EIF_REFERENCE F221_3306 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	tr1 = F216_3236(Current, arg1, arg2);
	loc1 = F221_3304(Current, tr1);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) -1L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F934_8260(RTCW(tr1), loc1);
		loc2 = tr1;
		tb1 = (EIF_TRUE);
	}
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(loc2 + _REFACS_2_);
		RTLE;
		return (EIF_REFERENCE) tr1;
	}
	RTLE;
	return (EIF_REFERENCE) 0;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.array */
EIF_REFERENCE F221_3309 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit189 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/i1189.c <==
/*
 * Code for class I18N_BINARY_SEARCH_ARRAY_DICTIONARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "i1189.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.make */
void F224_3104 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 223, Current, 0, 1, 3183);
	RTGC;
	RTHOOK(1);
	F223_3088(Current, arg1);
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {844,370,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F845_7389(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.extend */
void F224_3105 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("extend", 223, Current, 0, 1, 3184);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	F845_7416(RTCW(tr1), arg1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_));
	RTHOOK(2);
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_))++;
	RTHOOK(3);
	F224_3106(Current);
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.search_index_and_insert */
void F224_3106 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc8 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc9 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc4);
	RTLR(2,tr1);
	RTLR(3,loc5);
	RTLR(4,loc6);
	RTLR(5,loc7);
	RTLIU(6);
	
	RTEAA("search_index_and_insert", 223, Current, 9, 0, 3185);
	RTGC;
	RTHOOK(1);
	loc9 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc9 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	if ((EIF_BOOLEAN) (loc9 > ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc4 = F845_7395(RTCW(tr1), loc9);
		RTHOOK(4);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc5 = F845_7395(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc6 = F845_7395(RTCW(tr1), (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)));
		RTHOOK(6);
		tb1 = F371_5109(RTCW(loc4), loc5);
		if (tb1) {
			RTHOOK(7);
			loc8 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		} else {
			RTHOOK(8);
			tb1 = F370_5093(RTCW(loc4), loc6);
			if (tb1) {
				RTHOOK(9);
				loc8 = (EIF_INTEGER_32) loc9;
			} else {
				RTHOOK(10);
				loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
				RTHOOK(11);
				loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 2L));
				for (;;) {
					RTHOOK(12);
					if ((EIF_BOOLEAN) (loc1 > loc2)) break;
					RTHOOK(13);
					tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
					tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
					loc3 = (EIF_INTEGER_32) tu4_1;
					RTHOOK(14);
					tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
					loc7 = F845_7395(RTCW(tr1), loc3);
					RTHOOK(15);
					tb1 = F371_5109(RTCW(loc4), loc7);
					if (tb1) {
						RTHOOK(16);
						loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
					} else {
						RTHOOK(17);
						loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
					}
				}
				RTHOOK(18);
				loc8 = (EIF_INTEGER_32) loc1;
			}
		}
		RTHOOK(19);
		if ((EIF_BOOLEAN)(loc8 != loc9)) {
			RTHOOK(20);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F845_7419(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_1_), loc8, (EIF_INTEGER_32) (loc9 - ((EIF_INTEGER_32) 1L)), (EIF_INTEGER_32) (loc8 + ((EIF_INTEGER_32) 1L)));
			RTHOOK(21);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			F845_7414(RTCW(tr1), loc4, loc8);
		}
	}
	RTHOOK(22);
	RTLE;
	RTEE;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.has_index */
EIF_INTEGER_32 F224_3107 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN loc5 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc7 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc10 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc11 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc12 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_NATURAL_32 tu4_1;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc6);
	RTLR(2,arg1);
	RTLR(3,loc12);
	RTLR(4,tr1);
	RTLR(5,loc4);
	RTLIU(6);
	
	RTEAA("has_index", 223, Current, 12, 1, 3186);
	RTGC;
	RTHOOK(1);
	loc7 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
	loc7 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc7 - ((EIF_INTEGER_32) 1L));
	RTHOOK(2);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTHOOK(3);
	loc2 = (EIF_INTEGER_32) loc7;
	RTHOOK(4);
	loc6 = F1062_9304(RTCW(arg1));
	for (;;) {
		RTHOOK(8);
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || loc5)) break;
		RTHOOK(9);
		tu4_1 = (EIF_NATURAL_32) (EIF_INTEGER_32) (loc1 + loc2);
		tu4_1 = eif_bit_shift_right(tu4_1,((EIF_INTEGER_32) 1L));
		loc3 = (EIF_INTEGER_32) tu4_1;
		RTHOOK(10);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F845_7395(RTCW(tr1), loc3);
		loc12 = tr1;
		if (EIF_TEST(loc12)) {
			RTHOOK(11);
			loc4 = F371_5103(loc12);
		} else {
			
			RTHOOK(13);
			loc4 = RTLNS(eif_new_type(1066, 0x00).id, 1066, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F1062_9245(RTCW(loc4));
		}
		RTHOOK(14);
		tb1 = F1065_9403(RTCW(loc6), loc4);
		if (tb1) {
			RTHOOK(15);
			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
		} else {
			RTHOOK(16);
			tb1 = F370_5093(RTCW(loc6), loc4);
			if (tb1) {
				RTHOOK(17);
				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L));
			} else {
				RTHOOK(18);
				loc5 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
				RTHOOK(19);
				Result = (EIF_INTEGER_32) loc3;
				RTHOOK(20);
				loc1++;
			}
		}
	}
	RTHOOK(21);
	if ((EIF_BOOLEAN)(loc5 == (EIF_BOOLEAN) 0)) {
		RTHOOK(22);
		RTHOOK(23);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) ((EIF_INTEGER_32) -1L);
	}
	RTHOOK(24);
	RTLE;
	RTEE;
	return Result;
}

/* {I18N_BINARY_SEARCH_ARRAY_DICTIONARY}.singular_in_context */
EIF_REFERENCE F224_3109 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,arg2);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("singular_in_context", 223, Current, 2, 2, 3188);
	RTGC;
	RTHOOK(1);
	tr1 = F219_3039(Current, arg1, arg2);
	loc1 = F224_3107(Current, tr1);
	RTHOOK(2);
	tb1 = '\0';
	if ((EIF_BOOLEAN)(loc1 != ((EIF_INTEGER_32) -1L))) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr1 = F845_7395(RTCW(tr1), loc1);
		loc2 = tr1;
		tb1 = EIF_TEST(loc2);
	}
	if (tb1) {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(loc2 + _REFACS_2_);
		RTHOOK(4);
		RTLE;
		RTEE;
		return (EIF_REFERENCE) tr1;
	}
	RTHOOK(5);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

void EIF_Minit189 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
